# -*- coding: utf-8 -*-
##############################################################################
#
#    OpenObject Library
#    Copyright (C) 2009i-2010 Syleam (<http://syleam.fr>). Christophe Chauvet
#                  All Rights Reserved
#
#    This program is free software: you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation, either version 3 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
##############################################################################

"""Release information"""

name = "OpenObject-Library"
appname = name.lower()
version = '2.0.3'
copyright = "Copyright (C) 2009-2012 Christophe CHAUVET <christophe.chauvet@syleam.fr>"
description = "Web Services library OpenObject Framework"
author = "Christophe CHAUVET"
author_email = "christophe.chauvet@syleam.fr"
url = "https://github.com/syleam/openobject-library"
long_description = """OpenObject-Library is a library to manage
OpenObject Server
"""
classifiers="""
Development Status :: 5 - Production/Stable
Environment :: Console
License :: OSI Approved :: GNU Affero General Public License v3
Operating System :: OS Independent
Programming Language :: Python :: 2.4
Programming Language :: Python :: 2.5
Programming Language :: Python :: 2.6
Programming Language :: Python :: 2.7
Topic :: Software Development :: Libraries :: Python Modules
"""

# vim:expandtab:smartindent:tabstop=4:softtabstop=4:shiftwidth=4:
